@@ -59,6 +59,9 @@ AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     connect(m_accountsInter, &Accounts::UserListChanged, this, &AccountsWorker::onUserListChanged, Qt::QueuedConnection);
     connect(m_accountsInter, &Accounts::UserAdded, this, &AccountsWorker::addUser, Qt::QueuedConnection);
     connect(m_accountsInter, &Accounts::UserDeleted, this, &AccountsWorker::removeUser, Qt::QueuedConnection);
+    QDBusConnection::systemBus().connect("com.deepin.daemon.Accounts", "/com/deepin/daemon/Accounts",
+                                                  "org.freedesktop.DBus.Properties", "PropertiesChanged",
+                                                  "sa{sv}as", this, SLOT(handlePropertiesChanged(QDBusMessage)));
 
     connect(m_dmInter, &DisplayManager::SessionsChanged, this, &AccountsWorker::updateUserOnlineStatus);
 
@@ -111,6 +114,26 @@ void AccountsWorker::getAllGroupsResult(QDBusPendingCallWatcher *watch)
     QDBusPendingReply<QStringList> reply = *watch;
     if (!watch->isError()) {
         m_userModel->setAllGroups(reply.value());
+
+        QStringList disabledGroups;
+        QJsonDocument jsonDocument;
+        QJsonObject jsonObject;
+        QString info;
+
+        foreach (auto name, reply.value()) {
+            getGroupInfoByName(name, info);
+            jsonDocument = QJsonDocument::fromJson(info.toLocal8Bit());
+            jsonObject = jsonDocument.object();
+
+            bool res = false;
+            int gid = jsonObject.value("Gid").toString().toInt(&res);
+            if (res && 1000 > gid) {
+                if (!disabledGroups.contains(name))
+                    disabledGroups.append(name);
+            }
+        }
+        m_userModel->setDisabledGroups(disabledGroups);
+
     } else {
         qDebug() << "getAllGroupsResult error." << watch->error();
     }
@@ -138,10 +161,6 @@ void AccountsWorker::getPresetGroupsResult(QDBusPendingCallWatcher *watch)
 
 void AccountsWorker::getUOSID(QString &uosid)
 {
-    if (!m_syncHelperInter->isValid()) {
-        qWarning() << "syncHelper interface invalid: (getUOSID)" << m_syncHelperInter->lastError().message();
-        return;
-    }
     QDBusReply<QString> retUOSID = m_syncHelperInter->call("UOSID");
     if (retUOSID.error().message().isEmpty()) {
         uosid = retUOSID.value();
@@ -233,6 +252,52 @@ void AccountsWorker::setSecurityQuestions(User *user, const QMap<int, QByteArray
     }
 }
 
+void AccountsWorker::deleteGroup(const QString &group)
+{
+    QDBusPendingCall call = m_accountsInter->asyncCall("DeleteGroup", group, true);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [] (QDBusPendingCallWatcher* call) {
+        if (call->isError()) {
+            qDebug() << Q_FUNC_INFO << call->error().message();
+        }
+    });
+}
+
+void AccountsWorker::createGroup(const QString &group, uint32_t gid, bool isSystem)
+{
+    QDBusPendingCall call = m_accountsInter->asyncCall("CreateGroup", group, gid, isSystem);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [] (QDBusPendingCallWatcher* call) {
+        if (call->isError()) {
+            qDebug() << Q_FUNC_INFO << call->error().message();
+        }
+    });
+}
+
+void AccountsWorker::modifyGroup(const QString &oldGroup, const QString &newGroup, uint32_t gid)
+{
+    QDBusPendingCall call = m_accountsInter->asyncCall("ModifyGroup",oldGroup, newGroup, gid);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [] (QDBusPendingCallWatcher* call) {
+        if (call->isError()) {
+            qDebug() << Q_FUNC_INFO << call->error().message();
+        }
+    });
+}
+
+void AccountsWorker::getGroupInfoByName(const QString &groupName, QString &resInfoJson)
+{
+    QString info;
+    QDBusReply<QString> call = m_accountsInter->call("GetGroupInfoByName",groupName);
+    if (call.error().message().isEmpty()) {
+        resInfoJson = call.value();
+    } else {
+        qWarning() << "getGroupInfo failed:" << call.error().message();
+        resInfoJson.clear();
+        return;
+    }
+}
+
 bool AccountsWorker::hasOpenSecurity()
 {
     QDBusInterface securityEnhance("com.deepin.daemon.SecurityEnhance",
@@ -864,3 +929,23 @@ void AccountsWorker::checkPwdLimitLevel()
         Q_EMIT showSafeyPage(errorTips);
     }
 }
+
+void AccountsWorker::handlePropertiesChanged(QDBusMessage msg)
+{
+    QList<QVariant> arguments = msg.arguments();
+    if (3 != arguments.count()) {
+        return;
+    }
+
+    QString interfaceName = msg.arguments().at(0).toString();
+    if (interfaceName == "com.deepin.daemon.Accounts") {
+        QVariantMap changedProps = qdbus_cast<QVariantMap>(arguments.at(1).value<QDBusArgument>());
+        QStringList keys = changedProps.keys();
+        for (int i = 0; i < keys.size(); i++) {
+            if (keys.at(i) == "GroupList") {
+                Q_EMIT onGroupListChanged(changedProps.value(keys.at(i)).toStringList());
+                return;
+            }
+        }
+    }
+}
