@@ -4,7 +4,10 @@
 
 #include "usermodel.h"
 
+#include <QtDBus>
 #include <QDebug>
+#include <QJsonDocument>
+#include <QJsonObject>
 
 using namespace dcc::accounts;
 
@@ -131,6 +134,46 @@ void UserModel::setIsSecurityHighLever(bool isSecurityHighLever)
     m_isSecurityHighLever = isSecurityHighLever;
 }
 
+// 判断当前用户是否是域账户
+bool UserModel::isDomainUser(const QString &userName)
+{
+    // LDAP域账户
+    for(const auto &user : userList()) {
+        if (user->name() == userName) {
+            if (user->groups().contains("domain users")) {
+                return true;
+            }
+        }
+    }
+
+    QDBusInterface interface("com.deepin.udcp.iam",
+                             "/com/deepin/udcp/iam",
+                             "com.deepin.udcp.iam",
+                             QDBusConnection::systemBus());
+
+    if (!interface.isValid()) {
+        return false;
+    }
+
+    // 调用域管的接口获取当前用户的组，不为空为域管用户
+    QDBusReply<QStringList> reply = interface.call("GetUserGroups", userName);
+    if (reply.error().type() == QDBusError::NoError && !reply.value().isEmpty()) {
+        return true;
+    }
+
+    return false;
+}
+
+bool UserModel::isDisabledGroup(const QString &groupName)
+{
+    return m_DisabledGroups.contains(groupName);
+}
+
+void UserModel::setDisabledGroups(const QStringList &groups)
+{
+    m_DisabledGroups = groups;
+}
+
 #ifdef DCC_ENABLE_ADDOMAIN
 void UserModel::setIsJoinADDomain(bool isJoinADDomain)
 {
