@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     duanhongyu <duanhongyu@uniontech.com>
-
- * Maintainer: duanhongyu <duanhongyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "charamangermodel.h"
 
@@ -99,6 +82,11 @@ void CharaMangerModel::setInputIrisFD(CharaMangerModel::AddInfoState state)
     Q_EMIT tryStartInputIris(state);
 }
 
+void CharaMangerModel::setAddButtonStatus(const bool buttStatus)
+{
+    Q_EMIT addButtonStatusChange(buttStatus);
+}
+
 void CharaMangerModel::onEnrollStatusChanged(int code, const QString &msg)
 {
      // TODO： 处理所有录入状态提示信息
