@@ -141,10 +141,9 @@ QString CharaMangerWorker::getControlCenterDbusSender()
 
 void CharaMangerWorker::predefineDriverInfo(const QString &driverInfo)
 {
+    m_model->setFaceDriverVaild(false);
+    m_model->setIrisDriverVaild(false);
     if (driverInfo.isNull()) {
-        // 处理界面显示空设备
-        m_model->setFaceDriverVaild(false);
-        m_model->setIrisDriverVaild(false);
         return;
     }
     QStringList faceDriverNames;
@@ -160,17 +159,12 @@ void CharaMangerWorker::predefineDriverInfo(const QString &driverInfo)
         // 可用人脸driverName
         if (it.value() & FACE_CHARA) {
             faceDriverNames.append(it.key());
+            m_model->setFaceDriverVaild(true);
         }
 
         if (it.value() & IRIS_CHARA) {
             irisDriverNames.append(it.key());
-        }
-
-        if (it.value() == 0) {
-            // 处理界面显示空设备
-            m_model->setFaceDriverVaild(false);
-            m_model->setIrisDriverVaild(false);
-            return;
+            m_model->setIrisDriverVaild(true);
         }
     }
 
