@@ -6,7 +6,6 @@
 #include "interface/namespace.h"
 #include "widgets/settingsitem.h"
 
-#include <DAbstractDialog>
 #include <DSuggestButton>
 #include <DTipLabel>
 
@@ -21,35 +20,25 @@ namespace dcc {
 namespace authentication {
 
 enum DisclaimersObj {
-    Faceid,
+    FaceId,
     Iris,
-    Finge
+    Finger
 };
 
 // 免责声明对话框
-class DisclaimersDialog : public DTK_WIDGET_NAMESPACE::DAbstractDialog
+class DisclaimersDialog : public QWidget
 {
     Q_OBJECT
 public:
-    explicit DisclaimersDialog(DisclaimersObj disobj, DAbstractDialog *parent = nullptr);
+    explicit DisclaimersDialog(DisclaimersObj disobj, QWidget *parent = nullptr);
     ~DisclaimersDialog();
 
 private:
     void initWidget(DisclaimersObj state);
     void initConnect();
 
-protected:
-    void closeEvent(QCloseEvent *event) override;
-
 Q_SIGNALS:
-    /**
-     * @brief requestClickStatus 点击确定后 返回登陆界面 显示勾选状态
-     */
-    void requestClickStatus(bool isClick);
-    /**
-     * @brief requesetCloseDlg 离开免责对话框界面 需要恢复父窗口显示状态
-     */
-    void requesetCloseDlg(bool isClose);
+    void acceptDisclaimer(bool accept);
 
 private:
     QVBoxLayout *m_mainLayout;
