@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     duanhongyu <duanhongyu@uniontech.com>
-
- * Maintainer: duanhongyu <duanhongyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "faceinfowidget.h"
 
@@ -36,6 +19,8 @@
 using namespace dcc;
 using namespace dcc::authentication;
 
+bool FaceInfoWidget::EnableRecvImage = true;
+
 FaceInfoWidget::FaceInfoWidget(QWidget *parent)
     : QLabel (parent)
     , m_faceLable(new QLabel(this))
@@ -48,13 +33,14 @@ FaceInfoWidget::FaceInfoWidget(QWidget *parent)
 
     connect(m_startTimer, &QTimer::timeout, this, &FaceInfoWidget::onUpdateProgressbar);
     m_startTimer->start(100);
+    EnableRecvImage = true;
 }
 
 FaceInfoWidget::~FaceInfoWidget()
 {
     if (m_startTimer)
         m_startTimer->stop();
-    m_faceLable = nullptr;
+    EnableRecvImage = false;
 }
 
 void FaceInfoWidget::initWidget()
@@ -83,7 +69,7 @@ void FaceInfoWidget::onUpdateProgressbar()
 
 void FaceInfoWidget::recvCamara(void *const context, const DA_img *const img)
 {
-    if (!context)
+    if (!context || !EnableRecvImage)
         return;
 
     QLabel *label_ptr = static_cast<QLabel *>(context);
