@@ -11,6 +11,11 @@
 #include <QListView>
 #include <QMouseEvent>
 #include <QVBoxLayout>
+#include <QEvent>
+#include <QPainter>
+
+#include <DGuiApplicationHelper>
+
 #include "widgets/basiclistdelegate.h"
 
 #include "file_util.h"
@@ -18,6 +23,8 @@
 #include "popup_menu.h"
 #include "tooltip_pin.h"
 
+DGUI_USE_NAMESPACE
+
 namespace installer {
 
 namespace {
@@ -27,8 +34,8 @@ const int kZonePinHeight = 30;
 const int kZonePinMinimumWidth = 60;
 
 const double kDistanceThreshold = 64.0;
-const char kDotFile[] = ":/timezone_dialog/images/indicator_active.png";
 const char kTimezoneMapFile[] = ":/timezone_dialog/images/timezone_map_big@1x.svg";
+const char kTimezoneMapFile_Light[] = ":/timezone_dialog/images/timezone_map_big_light@1x.svg";
 
 // At absolute position of |zone| on a map with size (map_width, map_height).
 QPoint ZoneInfoToPosition(const ZoneInfo& zone, int map_width, int map_height) {
@@ -42,6 +49,7 @@ QPoint ZoneInfoToPosition(const ZoneInfo& zone, int map_width, int map_height) {
 
 TimezoneMap::TimezoneMap(QWidget* parent)
     : QFrame(parent),
+      m_systemActiveColor(QString("")),
       current_zone_(),
       total_zones_(GetZoneInfoList()),
       nearest_zones_() {
@@ -62,6 +70,13 @@ const QString TimezoneMap::getTimezone() const {
     return current_zone_.timezone;
 }
 
+void TimezoneMap::setSystemActiveColor(const QString &color)
+{
+    m_systemActiveColor = color;
+    dot_->setFixedSize(QSize(12, 12));
+    update();
+}
+
 bool TimezoneMap::setTimezone(const QString &timezone)
 {
     nearest_zones_.clear();
@@ -108,13 +123,45 @@ void TimezoneMap::resizeEvent(QResizeEvent* event) {
 
   QLabel *background_label = findChild<QLabel*>("background_label");
   if (background_label) {
-      QPixmap timezone_pixmap = loadPixmap(kTimezoneMapFile);
+      // kTimezoneMapFile_Light图片地图区域为黑色，其他区域为白色透明，与浅色主题界面保持一致
+      QPixmap timezone_pixmap = loadPixmap(kTimezoneMapFile_Light);
+      if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+          // kTimezoneMapFile 图片地图区域为白色，其他空白区域为黑色，与深色主题界面保持一致
+          timezone_pixmap = loadPixmap(kTimezoneMapFile);
+      }
       background_label->setPixmap(timezone_pixmap.scaled(event->size() * devicePixelRatioF(), Qt::KeepAspectRatio, Qt::FastTransformation));
   }
 
   QWidget::resizeEvent(event);
 }
 
+bool TimezoneMap::eventFilter(QObject *watcher, QEvent *event)
+{
+    if (watcher == dot_ && event->type() == QEvent::Paint) {
+        QPainter painter(dot_);
+        painter.setRenderHints(painter.renderHints() | QPainter::Antialiasing);
+
+        QColor destColor = QColor(m_systemActiveColor);
+
+        // 给dot_绘制透明背景
+        painter.setBrush(QBrush(Qt::white));
+        painter.setOpacity(0);
+        painter.drawRect(this->rect());
+
+        // 设置系统活动色
+        painter.setPen(QPen(QBrush(destColor),2,Qt::SolidLine));//设置画笔颜色
+        painter.setBrush(QBrush(destColor));//设置画刷颜色
+        painter.setOpacity(1);
+
+        // 绘制大小为10像素的圆形标记点
+        painter.drawEllipse(dot_->rect().adjusted(+1, +1, -1, -1));
+
+        return true;
+    }
+
+    return QFrame::eventFilter(watcher, event);
+}
+
 void TimezoneMap::initConnections() {
   // Hide dot when popup-zones window is hidden.
   connect(popup_window_, &PopupMenu::onHide,
@@ -138,16 +185,19 @@ void TimezoneMap::initConnections() {
 void TimezoneMap::initUI() {
   QLabel* background_label = new QLabel(this);
   background_label->setObjectName("background_label");
-  QPixmap timezone_pixmap = loadPixmap(kTimezoneMapFile);
+  // kTimezoneMapFile_Light 地图区域为黑色，其他区域为白色透明，与浅色主题界面保持一致
+  QPixmap timezone_pixmap = loadPixmap(kTimezoneMapFile_Light);
+  if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+      // kTimezoneMapFile 地图区域为白色，其他空白区域为黑色，与深色主题界面保持一致
+      timezone_pixmap = loadPixmap(kTimezoneMapFile);
+  }
   Q_ASSERT(!timezone_pixmap.isNull());
   background_label->setPixmap(timezone_pixmap);
 
   // Set parent widget of dot_ to SystemInfoTimezoneFrame.
   dot_ = new QLabel(this->parentWidget());
-  const QPixmap dot_pixmap(kDotFile);
-  Q_ASSERT(!dot_pixmap.isNull());
-  dot_->setPixmap(dot_pixmap);
-  dot_->setFixedSize(dot_pixmap.size());
+  dot_->installEventFilter(this);
+  dot_->setFixedSize(QSize(12, 12));
   dot_->hide();
 
   // Set parent widget of zone_pin_ to SystemInfoTimezoneFrame.
@@ -161,6 +211,7 @@ void TimezoneMap::initUI() {
   popup_window_ = new PopupMenu();
   popup_window_->hide();
 
+  this->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
   this->setContentsMargins(0, 0, 0, 0);
 }
 
