@@ -19,6 +19,7 @@ MouseModel::MouseModel(QObject *parent)
     , m_disTpad(false)
     , m_palmDetect(false)
     , m_tapclick(false)
+    , m_supportDisableWhileTyping(true)
     , m_doubleSpeed(1)
     , m_mouseMoveSpeed(1)
     , m_tpadMoveSpeed(1)
@@ -204,6 +205,23 @@ void MouseModel::setTapClick(bool tapclick)
     Q_EMIT tapClickChanged(tapclick);
 }
 
+void MouseModel::setTouchpadEnable(const bool touchpadEnable)
+{
+    if (m_touchpadEnable == touchpadEnable)
+        return;
+
+    m_touchpadEnable = touchpadEnable;
+    Q_EMIT touchpadEnableChanged(touchpadEnable);
+}
+
+void MouseModel::setSystemTouchpadExist(const bool exist)
+{
+    if (m_systemTouchpadExist == exist)
+        return;
+
+    m_systemTouchpadExist = exist;
+}
+
 void MouseModel::setScrollSpeed(uint speed)
 {
     if (m_scrollSpeed == speed)
@@ -213,3 +231,13 @@ void MouseModel::setScrollSpeed(uint speed)
 
     Q_EMIT scrollSpeedChanged(speed);
 }
+
+void MouseModel::setSupportDisbleWhileTyping(const bool state)
+{
+    if (m_supportDisableWhileTyping == state)
+        return;
+
+    m_supportDisableWhileTyping = state;
+
+    Q_EMIT supportDisbaleWhileTypingChanged(state);
+}
