@@ -68,10 +68,17 @@ public:
 
     bool tapclick() const { return m_tapclick; }
     void setTapClick(bool tapclick);
+    bool touchpadEnable() const { return m_touchpadEnable; }
+    void setTouchpadEnable(const bool touchpadEnable);
+    bool systemTouchpadExist() const { return m_systemTouchpadExist; }
+    void setSystemTouchpadExist(const bool exist);
 
     uint scrollSpeed() const { return m_scrollSpeed; }
     void setScrollSpeed(uint speed);
 
+    bool supportDisableWhileTyping() const { return m_supportDisableWhileTyping; };
+    void setSupportDisbleWhileTyping(const bool state);
+
 Q_SIGNALS:
     void leftHandStateChanged(bool state);
     void disIfTypingStateChanged(bool state);
@@ -90,7 +97,9 @@ Q_SIGNALS:
     void palmMinWidthChanged(int palmMinWidth);
     void palmMinzChanged(int palmMinz);
     void tapClickChanged(bool tapclick);
+    void touchpadEnableChanged(const bool touchpadEnable);
     void scrollSpeedChanged(uint speed);
+    void supportDisbaleWhileTypingChanged(bool supportDisableWhileTyping);
 
 private:
     bool m_leftHandState;
@@ -104,6 +113,9 @@ private:
     bool m_disTpad;
     bool m_palmDetect;
     bool m_tapclick;
+    bool m_touchpadEnable;
+    bool m_systemTouchpadExist;
+    bool m_supportDisableWhileTyping;
     int  m_doubleSpeed;
     int  m_mouseMoveSpeed;
     int  m_tpadMoveSpeed;
