@@ -32,6 +32,8 @@ public Q_SLOTS:
     void setDisTouchPad(const bool state);
     void setTapClick(const bool state);
     void setDouClick(const int &value);
+    void setTouchpadEnable(const bool state);
+    void setSystemTouchpadExist(const bool exist);
     void setMouseMotionAcceleration(const double &value);
     void setAccelProfile(const bool state);
     void setTouchpadMotionAcceleration(const double &value);
@@ -40,6 +42,7 @@ public Q_SLOTS:
     void setPalmMinWidth(int palmMinWidth);
     void setPalmMinz(int palmMinz);
     void setScrollSpeed(uint speed);
+    void setDeviceList(QString deviceList);
 
     void onLeftHandStateChanged(const bool state);
     void onMouseNaturalScrollStateChanged(const bool state);
@@ -47,6 +50,7 @@ public Q_SLOTS:
     void onDisTypingChanged(const bool state);
     void onDisTouchPadChanged(const bool state);
     void onTapClick(const bool state);
+    void onTouchpadEnable(const bool state);
     void onDouClickChanged(const int &value);
     void onMouseMotionAccelerationChanged(const int &value);
     void onAccelProfileChanged(const bool state);
@@ -69,10 +73,12 @@ Q_SIGNALS:
     void requestSetDisTouchPad(const bool state);
     void requestSetTapClick(const bool state);
     void requestSetDouClick(const int &value);
+    void requestSetTouchpadEnable(const bool state);
     void requestSetMouseMotionAcceleration(const double &value);
     void requestSetAccelProfile(const bool state);
     void requestSetTouchpadMotionAcceleration(const double &value);
     void requestSetTrackPointMotionAcceleration(const double &value);
+    void requestChangedSupportDisableWhileTyping(const bool state);
 
 private:
     int converToDouble(int value);
