@@ -19,6 +19,9 @@ using namespace dcc::personalization;
 const QString Service = "com.deepin.daemon.Appearance";
 const QString Path    = "/com/deepin/daemon/Appearance";
 const QString EffectMoveWindowArg = "kwin4_effect_translucency";
+const QString Scale = "kwin4_effect_scale";
+const QString Magiclamp = "magiclamp";
+const QString IsEffectSupported = "isEffectSupported";
 const QString StrIsOpenWM = "deepin wm";
 
 static const std::vector<int> OPACITY_SLIDER {
@@ -36,12 +39,13 @@ const QList<int> FontSizeList {11, 12, 13, 14, 15, 16, 18, 20};
 #endif
 
 PersonalizationWork::PersonalizationWork(PersonalizationModel *model, QObject *parent)
-    : QObject(parent),
-      m_model(model),
-      m_dbus(new Appearance(Service, Path, QDBusConnection::sessionBus(), this)),
-      m_wmSwitcher(new WMSwitcher("com.deepin.WMSwitcher", "/com/deepin/WMSwitcher", QDBusConnection::sessionBus(), this)),
-      m_wm(new WM("com.deepin.wm", "/com/deepin/wm", QDBusConnection::sessionBus(), this)),
-      m_effects(new Effects("org.kde.KWin", "/Effects", QDBusConnection::sessionBus(), this))
+    : QObject(parent)
+    , m_model(model)
+    , m_dbus(new Appearance(Service, Path, QDBusConnection::sessionBus(), this))
+    , m_wmSwitcher(new WMSwitcher("com.deepin.WMSwitcher", "/com/deepin/WMSwitcher", QDBusConnection::sessionBus(), this))
+    , m_wm(new WM("com.deepin.wm", "/com/deepin/wm", QDBusConnection::sessionBus(), this))
+    , m_effects(new Effects("org.kde.KWin", "/Effects", QDBusConnection::sessionBus(), this))
+    , m_isWayland(qEnvironmentVariable("XDG_SESSION_TYPE").contains("wayland"))
 {
     ThemeModel *cursorTheme      = m_model->getMouseModel();
     ThemeModel *windowTheme      = m_model->getWindowModel();
@@ -77,14 +81,13 @@ PersonalizationWork::PersonalizationWork(PersonalizationModel *model, QObject *p
         bool isMinEffect = m_setting->get(GSETTING_EFFECT_LOAD).toBool();
         m_model->setMiniEffect(isMinEffect);
         if (isMinEffect) {
-            m_effects->loadEffect("magiclamp");
+            m_effects->loadEffect(Magiclamp);
         } else {
-            m_effects->unloadEffect("magiclamp");
+            m_effects->unloadEffect(Magiclamp);
         }
     } else {
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(m_effects->isEffectLoaded("magiclamp"), this);
+        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(m_effects->isEffectLoaded(Magiclamp), this);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, [ = ] (QDBusPendingCallWatcher *watcher) {
-            qDebug() << watcher->error();
             if (!watcher->isError()) {
                 QDBusReply<bool> value = watcher->reply();
                 if (value) {
@@ -92,17 +95,12 @@ PersonalizationWork::PersonalizationWork(PersonalizationModel *model, QObject *p
                 } else {
                     m_model->setMiniEffect(0);
                 }
+            } else {
+                qWarning() << watcher->error();
             }
         });
     };
 
-    if (m_wmSwitcher && m_wmSwitcher->CurrentWM() == StrIsOpenWM && m_effects) {
-        bool isMoveWindow = m_effects->isEffectLoaded(EffectMoveWindowArg);
-        qDebug() << Q_FUNC_INFO << isMoveWindow;
-        m_model->setIsMoveWindow(isMoveWindow);
-        m_model->setIsMoveWindowDconfig(isMoveWindow);
-    }
-
     m_themeModels["gtk"]           = windowTheme;
     m_themeModels["icon"]          = iconTheme;
     m_themeModels["cursor"]        = cursorTheme;
@@ -113,6 +111,87 @@ PersonalizationWork::PersonalizationWork(PersonalizationModel *model, QObject *p
     m_wmSwitcher->setSync(false);
 }
 
+void PersonalizationWork::refreshEffectModule()
+{
+    QDBusInterface effects("org.kde.KWin", "/Effects", "org.kde.kwin.Effects", QDBusConnection::sessionBus(), this);
+    if (!effects.isValid()) {
+        qWarning() << " The interface of org.kde.kwin.Effects is invalid.";
+        return;
+    }
+
+    // 虚拟机同步调用接口后，不会有返回
+    // 需要先使用同步接口，在获取结果为false时，再使用异步接口
+    QDBusReply<bool> isScaleSupported = effects.call(IsEffectSupported, Scale);
+    m_model->setIsEffectSupportScale(isScaleSupported);
+    qInfo() << " [refreshEffectModule] effects.call(IsEffectSupported, Scale) : " << isScaleSupported.value();
+
+    QDBusReply<bool> isMagicSupported = effects.call(IsEffectSupported, Magiclamp);
+    m_model->setIsEffectSupportMagiclamp(isMagicSupported);
+    qInfo() << " [refreshEffectModule] effects.call(IsEffectSupported, Magiclamp) : " << isMagicSupported.value();
+
+    QDBusReply<bool> isMoveWinSupported = effects.call(IsEffectSupported, EffectMoveWindowArg);
+    m_model->setIsEffectSupportMoveWindow(isMoveWinSupported);
+    qInfo() << " [refreshEffectModule] effects.call(IsEffectSupported, EffectMoveWindowArg) : " << isMoveWinSupported.value();
+
+    // 当同步获取到数据为false，可能是kwin接口存在问题再用异步方式获取一次
+    if (!isScaleSupported) {
+        // 最小化时效果 : 缩放
+        QDBusPendingCall scaleEffectReply = effects.asyncCall(IsEffectSupported, Scale);
+        QDBusPendingCallWatcher *scaleEffectWatcher = new QDBusPendingCallWatcher(scaleEffectReply, this);
+        connect(scaleEffectWatcher, &QDBusPendingCallWatcher::finished, [this, scaleEffectReply, scaleEffectWatcher] {
+            scaleEffectWatcher->deleteLater();
+
+            if (scaleEffectReply.isError()) {
+                qWarning() << " isEffectSupported Failed to get kwin4_effect_scale state: " << scaleEffectReply.error().message();
+                return;
+            }
+
+            QDBusReply<bool> reply = scaleEffectReply.reply();
+            if (reply.value() && m_model) {
+                m_model->setIsEffectSupportScale(true);
+            }
+        });
+    }
+
+    if (!isMagicSupported) {
+        // 最小化时效果 : 魔灯
+        QDBusPendingCall magiclampEffectReply = effects.asyncCall(IsEffectSupported, Magiclamp);
+        QDBusPendingCallWatcher *magiclampEffectWatcher = new QDBusPendingCallWatcher(magiclampEffectReply, this);
+        connect(magiclampEffectWatcher, &QDBusPendingCallWatcher::finished, [this, magiclampEffectReply, magiclampEffectWatcher] {
+            magiclampEffectWatcher->deleteLater();
+
+            if (magiclampEffectReply.isError()) {
+                qWarning() << " isEffectSupported Failed to get magiclamp state: " << magiclampEffectReply.error().message();
+                return;
+            }
+
+            QDBusReply<bool> reply = magiclampEffectReply.reply();
+            if (reply.value() && m_model) {
+                m_model->setIsEffectSupportMagiclamp(true);
+            }
+        });
+    }
+
+    if (!isMoveWinSupported) {
+        // 移动窗口时启动特效
+        QDBusPendingCall translucencyEffectReply = effects.asyncCall(IsEffectSupported, EffectMoveWindowArg);
+        QDBusPendingCallWatcher *translucencyEffectWatcher = new QDBusPendingCallWatcher(translucencyEffectReply, this);
+        connect(translucencyEffectWatcher, &QDBusPendingCallWatcher::finished, [this, translucencyEffectReply, translucencyEffectWatcher] {
+            translucencyEffectWatcher->deleteLater();
+
+            if (translucencyEffectReply.isError()) {
+                qWarning() << " isEffectSupported Failed to get kwin4_effect_translucency state: " << translucencyEffectReply.error().message();
+                return;
+            }
+
+            QDBusReply<bool> reply = translucencyEffectReply.reply();
+            if (reply.value() && m_model) {
+                m_model->setIsEffectSupportMoveWindow(true);
+            }
+        });
+    }
+}
+
 void PersonalizationWork::active()
 {
     m_dbus->blockSignals(false);
@@ -189,8 +268,29 @@ void PersonalizationWork::addList(ThemeModel *model, const QString &type, const
 
 void PersonalizationWork::refreshWMState()
 {
-    QDBusPendingCallWatcher *wmWatcher = new QDBusPendingCallWatcher(m_wmSwitcher->CurrentWM(), this);
-    connect(wmWatcher, &QDBusPendingCallWatcher::finished, this, &PersonalizationWork::onGetCurrentWMFinished);
+    // wayland默认支持且开启特效
+    if (m_isWayland) {
+        refreshMoveWindowState();
+    } else {
+        QDBusPendingCallWatcher *wmWatcher = new QDBusPendingCallWatcher(m_wmSwitcher->CurrentWM(), this);
+        connect(wmWatcher, &QDBusPendingCallWatcher::finished, this, &PersonalizationWork::onGetCurrentWMFinished);
+    }
+}
+
+void PersonalizationWork::refreshMoveWindowState()
+{
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(m_effects->isEffectLoaded(EffectMoveWindowArg), this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [ = ] (QDBusPendingCallWatcher *watcher) {
+        if (!watcher->isError()) {
+            QDBusReply<bool> isMoveWindow = watcher->reply();
+            qDebug() << Q_FUNC_INFO << isMoveWindow;
+            m_model->setIsMoveWindow(isMoveWindow);
+            m_model->setIsMoveWindowDconfig(isMoveWindow);
+        } else {
+            qWarning() << "[refreshMoveWindowState] isEffectLoaded err : " << watcher->error();
+        }
+        watcher->deleteLater();
+    });
 }
 
 void PersonalizationWork::FontSizeChanged(const double value) const
@@ -208,7 +308,7 @@ void PersonalizationWork::onGetFontFinished(QDBusPendingCallWatcher *w)
 
         setFontList(m_fontModels[category], category, reply.value());
     } else {
-        qDebug() << reply.error();
+        qWarning() << reply.error();
     }
 
     w->deleteLater();
@@ -224,7 +324,7 @@ void PersonalizationWork::onGetThemeFinished(QDBusPendingCallWatcher *w)
 
         addList(m_themeModels[category], category, array);
     } else {
-        qDebug() << reply.error();
+        qWarning() << reply.error();
     }
 
     w->deleteLater();
@@ -240,7 +340,7 @@ void PersonalizationWork::onGetPicFinished(QDBusPendingCallWatcher *w)
 
         m_themeModels[category]->addPic(id, reply.value());
     } else {
-        qDebug() << reply.error();
+        qWarning() << reply.error();
     }
 
     w->deleteLater();
@@ -253,7 +353,7 @@ void PersonalizationWork::onGetActiveColorFinished(QDBusPendingCallWatcher *w)
     if (!reply.isError()) {
         m_model->setActiveColor(reply.value());
     } else {
-        qDebug() << reply.error();
+        qWarning() << reply.error();
     }
 
     w->deleteLater();
@@ -275,6 +375,9 @@ void PersonalizationWork::onToggleWM(const QString &wm)
     bool is3D = wm == StrIsOpenWM;
     qDebug() << "onToggleWM: " << wm << is3D;
     m_model->setIs3DWm(is3D);
+    if (is3D) {
+        refreshMoveWindowState();
+    }
 }
 
 void PersonalizationWork::setMoveWindow(bool state)
@@ -552,15 +655,25 @@ void PersonalizationWork::movedWindowSwitchWM(bool value)
     }
 
     if (value) {
-        bool isload = m_effects->loadEffect(EffectMoveWindowArg);
-        qDebug() << Q_FUNC_INFO << " The effect of  kwin4_effect_translucency is : " << isload;
-        m_model->setIsMoveWindow(isload);
-        m_model->setIsMoveWindowDconfig(isload);
+        m_effects->loadEffect(EffectMoveWindowArg);
     } else {
         m_effects->unloadEffect(EffectMoveWindowArg);
-        m_model->setIsMoveWindow(false);
-        m_model->setIsMoveWindowDconfig(false);
     }
+
+    //设置kwin接口后, 等待50ms给kwin反应，根据isEffectLoaded调用的异步返回值确定真实状态
+    QTimer::singleShot(50, [this] {
+        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(m_effects->isEffectLoaded(EffectMoveWindowArg), this);
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, [ = ] (QDBusPendingCallWatcher *watcher) {
+            if (!watcher->isError()) {
+                QDBusReply<bool> value = watcher->reply();
+                qDebug() << Q_FUNC_INFO << " isEffectLoaded('kwin4_effect_translucency') : " << value;
+                m_model->setIsMoveWindow(value);
+                m_model->setIsMoveWindowDconfig(value);
+            } else {
+                qWarning() << Q_FUNC_INFO << " isEffectLoaded('kwin4_effect_translucency'), error : " << watcher->error();;
+            }
+        });
+    });
 }
 
 void PersonalizationWork::setOpacity(int opacity)
