@@ -42,11 +42,6 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
                                         "/com/deepin/daemon/Grub2/Theme",
                                         QDBusConnection::systemBus(), this);
 
-    m_dbusHostName = new HostNameDbus("org.freedesktop.hostname1",
-                                      "/org/freedesktop/hostname1",
-                                      QDBusConnection::systemBus(), this);
-
-
 
 #if 0
     //预留接口
@@ -55,30 +50,43 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
                                         "com.deepin.license.Info", this);
 #endif
 
+    QString validFrequency = "CurrentSpeed";
     QDBusInterface Interface("com.deepin.daemon.SystemInfo",
                              "/com/deepin/daemon/SystemInfo",
                              "org.freedesktop.DBus.Properties",
                              QDBusConnection::sessionBus());
-    QDBusMessage reply = Interface.call("Get", "com.deepin.daemon.SystemInfo", "CurrentSpeed");
+    QDBusMessage replyCPU = Interface.call("Get", "com.deepin.daemon.SystemInfo", "CPUHardware");
+    QList<QVariant> outArgsCPU = replyCPU.arguments();
+    if (outArgsCPU.count()) {
+        QString cpuHardware = outArgsCPU.at(0).value<QDBusVariant>().variant().toString();
+        qInfo() << Q_FUNC_INFO << "Current cpuHardware:" << cpuHardware;
+        if (cpuHardware.contains("PANGU")) {
+            validFrequency = "CPUMaxMHz";
+        }
+    }
+    double cpuMaxMhz = 0.0;
+    QDBusMessage reply = Interface.call("Get", "com.deepin.daemon.SystemInfo", validFrequency);
     QList<QVariant> outArgs = reply.arguments();
-    double cpuMaxMhz = outArgs.at(0).value<QDBusVariant>().variant().toDouble();
+    if (outArgs.count()) {
+        cpuMaxMhz = outArgs.at(0).value<QDBusVariant>().variant().toDouble();
+    }
     if (DSysInfo::cpuModelName().contains("Hz")) {
         m_model->setProcessor(DSysInfo::cpuModelName());
     } else {
         if (DSysInfo::cpuModelName().isEmpty()){
             QDBusMessage replyCpuInfo = Interface.call("Get", "com.deepin.daemon.SystemInfo", "Processor");
             QList<QVariant> outArgsCpuInfo = replyCpuInfo.arguments();
-            QString processor = outArgsCpuInfo.at(0).value<QDBusVariant>().variant().toString();
-            m_model->setProcessor(QString("%1 @ %2GHz").arg(processor)
-                                  .arg(cpuMaxMhz / 1000));
+            if (outArgsCpuInfo.count()) {
+                QString processor = outArgsCpuInfo.at(0).value<QDBusVariant>().variant().toString();
+                m_model->setProcessor(QString("%1 @ %2GHz").arg(processor)
+                                      .arg(cpuMaxMhz / 1000));
+            }
         } else {
             m_model->setProcessor(QString("%1 @ %2GHz").arg(DSysInfo::cpuModelName())
                                   .arg(cpuMaxMhz / 1000));
         }
     }
 
-    m_model->setHostName(m_dbusHostName->staticHostname());
-
     QDBusConnection::sessionBus().connect("com.deepin.daemon.SystemInfo",
                                           "/com/deepin/daemon/SystemInfo",
                                           "org.freedesktop.DBus.Properties",
@@ -88,7 +96,7 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
 
     m_dbusGrub->setSync(false, false);
     m_dbusGrubTheme->setSync(false, false);
-    m_dbusHostName->setSync(false, false);
+
 
     if (DSysInfo::isDeepin()) {
         QDBusConnection::systemBus().connect("com.deepin.license", "/com/deepin/license/Info",
@@ -109,22 +117,12 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
     }, Qt::QueuedConnection);
 
     connect(m_dbusGrubTheme, &GrubThemeDbus::BackgroundChanged, this, &SystemInfoWork::onBackgroundChanged);
-    connect(m_dbusHostName, &HostNameDbus::StaticHostnameChanged, m_model, &SystemInfoModel::setHostName);
+
     connect(m_systemInfoInter, &__SystemInfo::DistroIDChanged, m_model, &SystemInfoModel::setDistroID);
     connect(m_systemInfoInter, &__SystemInfo::DistroVerChanged, m_model, &SystemInfoModel::setDistroVer);
     connect(m_systemInfoInter, &__SystemInfo::DiskCapChanged, m_model, &SystemInfoModel::setDisk);
 
-    connect(m_model,&SystemInfoModel::setHostNameChanged, this, [this](const QString& hostName){
-        m_dbusHostName->SetStaticHostname(hostName,1);
-        QDBusPendingReply<QString> reply = m_dbusHostName->asyncCall("SetStaticHostname",hostName,true);
-        reply.waitForFinished();
-        if (reply.isError()) {
-            qDebug()<<"E:"<<(reply.error().message());
-            QString str = reply.error().message();
-            if(str.contains("hostname"))
-                m_model->setHostNameError(str);
-        }
-    });
+
 
     QProcess process;
     process.start("uname -r");
@@ -140,6 +138,28 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
 void SystemInfoWork::activate()
 {
     qRegisterMetaType<ActiveState>("ActiveState");
+
+    // 优化SystemInfo加载速度，避免初始化时启动hostname1接口影响程序启动
+    m_dbusHostName = new HostNameDbus("org.freedesktop.hostname1",
+                                      "/org/freedesktop/hostname1",
+                                      QDBusConnection::systemBus(), this);
+
+    m_model->setHostName(m_dbusHostName->staticHostname());
+
+    m_dbusHostName->setSync(false, false);
+    connect(m_dbusHostName, &HostNameDbus::StaticHostnameChanged, m_model, &SystemInfoModel::setHostName);
+    connect(m_model,&SystemInfoModel::setHostNameChanged, this, [this](const QString& hostName){
+        m_dbusHostName->SetStaticHostname(hostName,1);
+        QDBusPendingReply<QString> reply = m_dbusHostName->asyncCall("SetStaticHostname",hostName,true);
+        reply.waitForFinished();
+        if (reply.isError()) {
+            qDebug()<<"E:"<<(reply.error().message());
+            QString str = reply.error().message();
+            if(str.contains("hostname"))
+                m_model->setHostNameError(str);
+        }
+    });
+
     m_model->setDistroID(m_systemInfoInter->distroID());
     m_model->setDistroVer(m_systemInfoInter->distroVer());
     m_model->setDisk(m_systemInfoInter->diskCap());
