@@ -782,7 +782,7 @@ void UpdateWorker::distUpgrade(ClassifyUpdateType updateType)
     bool bConfigVlid = m_model->recoverConfigValid();
     qDebug() << Q_FUNC_INFO << " [abRecovery] 更新前,检查备份配置是否满足(true:满足) : " << bConfigVlid;
 
-    if (bConfigVlid) { //系统环境配置为可以恢复,在收到jobEnd()后,且"backup",成功,后才会继续到下一步下载数据
+    if (bConfigVlid && status != UpdatesStatus::UpdateFailed) { //系统环境配置为可以恢复,在收到jobEnd()后,且"backup",成功,后才会继续到下一步下载数据
         recoveryCanBackup(updateType);
     } else { //系统环境配置不满足,则直接跳到下一步下载数据
         qDebug() << Q_FUNC_INFO << " [abRecovery] 备份配置环境不满足,继续更新.";
@@ -853,6 +853,11 @@ void UpdateWorker::checkTestingChannelStatus()
         if (status == "joined") {
             m_model->setTestingChannelStatus(UpdateModel::TestingChannelStatus::Joined);
             qDebug() << "Testing:" << "Install testing channel package";
+            // 安装内测源之前执行一次apt update，避免刚安装的系统没有仓库索引导致安装失败
+            checkForUpdates();
+            // 延迟1秒是为了把安装任务放在update之后
+            QThread::sleep(1);
+            // lastore会自动等待apt update完成后再执行安装。
             m_managerInter->InstallPackage("testing channel", TestingChannelPackage);
             return;
         }
@@ -874,6 +879,18 @@ void UpdateWorker::setTestingChannelEnable(const bool &enable)
     const auto server = m_model->getTestingChannelServer();
     const auto machineID = m_model->getMachineID();
 
+    // 无论是加入还是退出都先在服务器标记退出
+    // 避免重装系统后机器码相同，没申请就自动加入
+    auto http = new QNetworkAccessManager(this);
+    QNetworkRequest request;
+    request.setUrl(QUrl(server + QString("/api/v2/public/testing/machine/") + machineID));
+    request.setRawHeader("content-type", "application/json");
+    connect(http, &QNetworkAccessManager::finished, this, [ http ](QNetworkReply *reply){
+        reply->deleteLater();
+        http->deleteLater();
+    });
+    http->deleteResource(request);
+
     /* Disable Testing Channel */
     if (!enable) {
         // Uninstall testing source package if it is installed
@@ -881,16 +898,6 @@ void UpdateWorker::setTestingChannelEnable(const bool &enable)
             qDebug() << "Testing:" << "Uninstall testing channel package";
             m_managerInter->RemovePackage("testing channel", TestingChannelPackage);
         }
-        // Send status to server
-        auto http = new QNetworkAccessManager(this);
-        QNetworkRequest request;
-        request.setUrl(QUrl(server + QString("/api/v2/public/testing/machine/") + machineID));
-        request.setRawHeader("content-type", "application/json");
-        connect(http, &QNetworkAccessManager::finished, this, [ = ](QNetworkReply *reply){
-            reply->deleteLater();
-            http->deleteLater();
-        });
-        http->deleteResource(request);
         return;
     }
 
@@ -934,7 +941,7 @@ QString UpdateWorker::getTestingChannelSource()
 QStringList UpdateWorker::getSourcesOfPackage(const QString pkg, const QString version)
 {
     QStringList sources;
-    QProcess aptCacheProcess;
+    QProcess aptCacheProcess(this);
     QStringList args;
     args.append("madison");
     args.append(pkg);
@@ -964,8 +971,11 @@ QStringList UpdateWorker::getSourcesOfPackage(const QString pkg, const QString v
 // checkCanExitTestingChannel check if the current env can exit internal test channel
 void UpdateWorker::checkCanExitTestingChannel()
 {
+    // 如果在执行apt-get clean之后使用apt-cache会很慢，比正常情况慢23倍
+    // 执行一次apt update，可以让apt-cache恢复到正常速度
+    checkForUpdates();
     auto testingChannelSource = getTestingChannelSource();
-    QProcess dpkgProcess;
+    QProcess dpkgProcess(this);
     // exec dpkg -l
     dpkgProcess.start("dpkg", QStringList("-l"));
     dpkgProcess.waitForStarted();
@@ -1823,6 +1833,10 @@ void UpdateWorker::onClassifiedUpdatablePackagesChanged(QMap<QString, QStringLis
 
 void UpdateWorker::onFixError(const ClassifyUpdateType &updateType, const QString &errorType)
 {
+    if (errorType == "noNetwork") {
+        this->checkForUpdates();
+        return;
+    }
     m_fixErrorUpdate.append(updateType);
     if (m_fixErrorJob != nullptr) {
         return;
