@@ -1,28 +1,9 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Technology Co., Ltd.
- *
- * Author:     Tianlu Shao <shaotianlu@uniontech.com>
- *
- * Maintainer: Tianlu Shao <shaotianlu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dconfigwatcher.h"
 
-#include <DConfig>
-
 #include <QListView>
 #include <QStandardItem>
 #include <QStandardItemModel>
@@ -236,6 +217,20 @@ const QString DConfigWatcher::getStatus(ModuleType moduleType, const QString &co
     return m_mapModulesConfig[QMetaEnum::fromType<ModuleType>().valueToKey(moduleType)]->value(configName).toString();
 }
 
+/**
+ * @brief DConfigWatcher::getValue   获取三级控件状态
+ * @param moduleType                 模块类型
+ * @param configName                 key值
+ * @return
+ */
+const QVariant DConfigWatcher::getValue(DConfigWatcher::ModuleType moduleType, const QString &configName)
+{
+    QString moduleName;
+    if (!existKey(moduleType, configName, moduleName))
+        return QVariant();
+    return m_mapModulesConfig[QMetaEnum::fromType<ModuleType>().valueToKey(moduleType)]->value(configName);
+}
+
 /**
  * @brief DConfigWatcher::getMenuState
  * @return second menu state
@@ -245,6 +240,22 @@ QMap<DConfigWatcher::ModuleKey *, bool> DConfigWatcher::getMenuState()
     return m_menuState;
 }
 
+/**
+ * @brief DConfigWatcher::setValue   获取三级控件状态
+ * @param moduleType                 模块类型
+ * @param configName                 key值
+ * @param data                       设置的值
+ * @return
+ */
+void DConfigWatcher::setValue(DConfigWatcher::ModuleType moduleType, const QString &configName, QVariant data)
+{
+    QString moduleName;
+    if (!existKey(moduleType, configName, moduleName)) {
+        return;
+    }
+    m_mapModulesConfig[QMetaEnum::fromType<ModuleType>().valueToKey(moduleType)]->setValue(configName, data);
+}
+
 /**
  * @brief 设置控件对应的显示类型
  * @param moduleType                 模块类型
