@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2019 ~ 2020 Untion Tech Technology Co., Ltd.
- *
- * Author:     niecheng <niejiashan@163.com>
- *
- * Maintainer: niecheng <niejiashan@163.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "insertplugin.h"
 
 #include <QGSettings>
@@ -34,13 +18,15 @@ QPointer<InsertPlugin> InsertPlugin::INSTANCE = nullptr;
 InsertPlugin::InsertPlugin(QObject *obj, FrameProxyInterface *frameProxy)
 {
     QDir moduleDir(ModuleDirectory);
-    if (!moduleDir.exists()) {
+    if (!moduleDir.exists())
+    {
         qDebug() << "module directory not exists";
         return;
     }
 
     auto moduleList = moduleDir.entryInfoList();
-    for (auto i : moduleList) {
+    for (auto i : moduleList)
+    {
         QString path = i.absoluteFilePath();
 
         if (!QLibrary::isLibrary(path))
@@ -52,13 +38,15 @@ InsertPlugin::InsertPlugin(QObject *obj, FrameProxyInterface *frameProxy)
         et.start();
         QPluginLoader loader(path);
         const QJsonObject &meta = loader.metaData().value("MetaData").toObject();
-        if (!compareVersion(meta.value("api").toString(), "1.0.0")) {
+        if (!compareVersion(meta.value("api").toString(), "1.0.0"))
+        {
             qDebug() << "plugin's version is too low";
             continue;
         }
 
         QObject *instance = loader.instance();
-        if (!instance) {
+        if (!instance)
+        {
             qDebug() << loader.errorString();
             continue;
         }
@@ -66,14 +54,16 @@ InsertPlugin::InsertPlugin(QObject *obj, FrameProxyInterface *frameProxy)
         instance->setParent(obj);
 
         auto *module = qobject_cast<ModuleInterface *>(instance);
-        if (!module) {
+        if (!module)
+        {
             return;
         }
         qDebug() << "load plugin Name: " << module->name() << module->displayName();
         qDebug() << "load this plugin using time: " << et.elapsed() << "ms";
         module->setFrameProxy(frameProxy);
 
-        if (module->follow() != MAINWINDOW && frameProxy) {
+        if (module->follow() != MAINWINDOW && frameProxy)
+        {
             frameProxy->setSearchPath(module);
         }
 
@@ -90,8 +80,10 @@ bool InsertPlugin::updatePluginInfo(QString moduleName)
 {
     m_currentPlugins.clear();
 
-    for (auto pluginSetting : m_allModules) {
-        if (pluginSetting.first.path == moduleName) {
+    for (auto pluginSetting : m_allModules)
+    {
+        if (pluginSetting.first.path == moduleName)
+        {
             m_currentPlugins << pluginSetting;
         }
     }
@@ -109,8 +101,10 @@ InsertPlugin *InsertPlugin::instance(QObject *obj, FrameProxyInterface *FramePro
 
 void InsertPlugin::preInitialize(QString moduleName)
 {
-    for (auto pluginSetting : m_allModules) {
-        if (pluginSetting.first.path == moduleName) {
+    for (auto pluginSetting : m_allModules)
+    {
+        if (pluginSetting.first.path == moduleName)
+        {
             auto *module = qobject_cast<ModuleInterface *>(pluginSetting.second.first);
             // 调用模块初始化函数搜索数据
             module->preInitialize(false);
@@ -121,7 +115,8 @@ void InsertPlugin::preInitialize(QString moduleName)
 
 ModuleInterface *InsertPlugin::pluginInterface(const QString &displayName)
 {
-    for (const auto &plugin : m_currentPlugins) {
+    for (const auto &plugin : m_currentPlugins)
+    {
         auto *module = qobject_cast<ModuleInterface *>(plugin.second.first);
         if (module->name() == displayName)
             return module;
@@ -136,7 +131,8 @@ ModuleInterface *InsertPlugin::pluginInterface(const QString &displayName)
 void dccV20::InsertPlugin::pushPlugin(QList<QPair<dccV20::ModuleInterface *, QString>> &modules)
 {
     // 一级菜单插件配置mainwindow
-    for (int i = 0; i < m_currentPlugins.size(); i++) {
+    for (int i = 0; i < m_currentPlugins.size(); i++)
+    {
         auto *module = qobject_cast<ModuleInterface *>(m_currentPlugins.at(i).second.first);
 
         // 查看插件是否定义为可用
@@ -148,26 +144,32 @@ void dccV20::InsertPlugin::pushPlugin(QList<QPair<dccV20::ModuleInterface *, QSt
         int index = m_currentPlugins.at(i).first.follow.toInt(&ok);
 
         // 类型为字符串时
-        if (!ok) {
+        if (!ok)
+        {
             // 字符串为空时，默认置底
-            if (m_currentPlugins.at(i).first.follow.isEmpty()) {
+            if (m_currentPlugins.at(i).first.follow.isEmpty())
+            {
                 modules.append({module, module->displayName()});
                 return;
             }
 
             // 遍历modules查找插入位置
-            auto res = std::find_if(modules.begin(), modules.end(), [=](const QPair<ModuleInterface *, QString> &data) -> bool {
-                return data.first->name() == m_currentPlugins.at(i).first.follow;
-            });
+            auto res = std::find_if(modules.begin(), modules.end(), [=](const QPair<ModuleInterface *, QString> &data) -> bool
+                                    { return data.first->name() == m_currentPlugins.at(i).first.follow; });
 
             // 若未找到则不添加插件
-            if (res != modules.end()) {
+            if (res != modules.end())
+            {
                 modules.insert(modules.indexOf(*res) + 1, {module, module->displayName()});
-            } else {
+            }
+            else
+            {
                 qWarning() << "insert module failed, no module named " << module->follow();
                 modules.append({module, module->displayName()});
             }
-        } else {
+        }
+        else
+        {
             // 为数字时直接插入到指定位置
             modules.insert(index, {module, module->displayName()});
         }
@@ -181,11 +183,13 @@ void dccV20::InsertPlugin::pushPlugin(QList<QPair<dccV20::ModuleInterface *, QSt
  */
 void dccV20::InsertPlugin::pushPlugin(QStandardItemModel *Model, QList<dccV20::ListSubItem> &itemList)
 {
-    for (int i = 0; i < m_currentPlugins.size(); i++) {
+    for (int i = 0; i < m_currentPlugins.size(); i++)
+    {
         QByteArray normalizedSignature = QMetaObject::normalizedSignature("active()");
         int methodIndex = m_currentPlugins.at(i).second.first->metaObject()->indexOfMethod(normalizedSignature);
         // 找不到对应激活的方法
-        if (methodIndex == -1) {
+        if (methodIndex == -1)
+        {
             continue;
         }
 
@@ -209,20 +213,28 @@ void dccV20::InsertPlugin::pushPlugin(QStandardItemModel *Model, QList<dccV20::L
         int index = m_currentPlugins.at(i).first.follow.toInt(&ok);
 
         //二级菜单插件的位置，为非数字默认置底
-        if (ok) {
-            if (index > Model->rowCount()) {
+        if (ok)
+        {
+            if (index > Model->rowCount())
+            {
                 itemList.append({module->name(), module->displayName(),
                                  metaMethod, m_currentPlugins.at(i).second.first});
                 Model->appendRow(item);
-            } else {
+            }
+            else
+            {
                 itemList.insert(index - 1, {module->name(), module->displayName(),
                                             metaMethod, m_currentPlugins.at(i).second.first});
                 Model->insertRow(index - 1, item);
             }
-        } else {
+        }
+        else
+        {
             bool isLoad = false;
-            for (int k = 0; k < Model->rowCount(); k++) {
-                if (Model->item(k)->text() == m_currentPlugins.at(i).first.follow) {
+            for (int k = 0; k < Model->rowCount(); k++)
+            {
+                if (Model->item(k)->text() == m_currentPlugins.at(i).first.follow)
+                {
                     itemList.insert(k + 1, {module->name(), module->displayName(),
                                             metaMethod, m_currentPlugins.at(i).second.first});
                     Model->insertRow(k + 1, item);
@@ -230,7 +242,8 @@ void dccV20::InsertPlugin::pushPlugin(QStandardItemModel *Model, QList<dccV20::L
                     break;
                 }
             }
-            if (!isLoad) {
+            if (!isLoad)
+            {
                 itemList.append({module->name(), module->displayName(),
                                  metaMethod, m_currentPlugins.at(i).second.first});
                 Model->appendRow(item);
@@ -249,7 +262,8 @@ QStringList InsertPlugin::availPages(const QString &moduleName)
     updatePluginInfo(moduleName);
 
     QStringList pages;
-    for (auto it : m_currentPlugins) {
+    for (auto it : m_currentPlugins)
+    {
         if (it.first.path != moduleName)
             continue;
 
