@@ -13,6 +13,7 @@
 #include "modules/keyboard/keyboardmodule.h"
 #include "modules/power/powermodule.h"
 #include "modules/sound/soundmodule.h"
+#include "modules/privacy/privacymodule.h"
 #ifndef DISABLE_SYS_UPDATE
 #include "modules/update/updatemodule.h"
 #endif
@@ -40,6 +41,7 @@
 #include <DIconButton>
 #include <DApplicationHelper>
 #include <DSlider>
+#include <DConfig>
 
 #include <QScrollArea>
 #include <QHBoxLayout>
@@ -103,6 +105,7 @@ MainWindow::MainWindow(QWidget *parent)
     , m_backwardBtn(nullptr)
     , m_lastSize(WidgetMinimumWidth, WidgetMinimumHeight)
     , m_primaryScreen(nullptr)
+    , m_fontSize(getAppearanceFontSize())
 {
     //Initialize view and layout structure
     DMainWindow::installEventFilter(this);
@@ -209,6 +212,12 @@ MainWindow::MainWindow(QWidget *parent)
         resetNavList(m_contentStack.isEmpty());
     });
     updateViewBackground();
+    QDBusConnection::sessionBus().connect("com.deepin.daemon.Appearance",
+                                          "/com/deepin/daemon/Appearance",
+                                          "org.freedesktop.DBus.Properties",
+                                          "PropertiesChanged",
+                                          "sa{sv}as",
+                                          this, SLOT(handleAppearanceDbusSignal(QDBusMessage)));
 }
 
 MainWindow::~MainWindow()
@@ -306,9 +315,7 @@ void MainWindow::setPrimaryScreen(QScreen *screen)
     updateWinsize();
     connect(m_primaryScreen, &QScreen::geometryChanged, this, &MainWindow::updateWinsize);
     // 主屏变化后，根据新主屏的分辨率移动窗口居中
-    connect(qApp, &QGuiApplication::primaryScreenChanged, this, [this] {
-        updateWinsize(m_primaryScreen->geometry());
-    });
+    connect(qApp, &QGuiApplication::primaryScreenChanged, this, &MainWindow::updateWinsize);
 }
 
 QScreen *MainWindow::primaryScreen() const
@@ -362,6 +369,7 @@ void MainWindow::initAllModule(const QString &m)
         { new MouseModule(this), tr("Mouse")},
         { new WacomModule(this), tr("Drawing Tablet")},
         { new KeyboardModule(this), tr("Keyboard and Language")},
+        { new PrivacyModule(this), tr("Privacy and Security")},
 #ifndef DISABLE_SYS_UPDATE
         { new UpdateModule(this), tr("Updates")},
 #endif
@@ -369,7 +377,7 @@ void MainWindow::initAllModule(const QString &m)
         { new CommonInfoModule(this), tr("General Settings")},
     };
     // V20 对Deepinid 进行差异化处理  UnionID 走插件化
-    if (!IsProfessionalSystem) {
+    if (showSyncModule()) {
          m_modules.insert(3, {new SyncModule(this), DSysInfo::isCommunityEdition() ? "Deepin ID" : "UOS ID"});
     }
     //读取加载一级菜单的插件
@@ -429,7 +437,6 @@ void MainWindow::initAllModule(const QString &m)
     resetNavList(isIcon);
 
     modulePreInitialize(m);
-    updateModuleVisible();
 
     QElapsedTimer et;
     et.start();
@@ -438,7 +445,7 @@ void MainWindow::initAllModule(const QString &m)
     qDebug() << QString("load search info with %1ms").arg(et.elapsed());
 }
 
-void MainWindow::updateWinsize(QRect rect)
+void MainWindow::updateWinsize()
 {
     if (!qApp->screens().contains(m_primaryScreen))
         return;
@@ -477,9 +484,7 @@ void MainWindow::updateModuleVisible()
     m_hideModuleNames = m_moduleSettings->get(GSETTINGS_HIDE_MODULE).toStringList();
     for (auto i : m_modules) {
 
-        if (m_hideModuleNames.contains((i.first->name()))) {
-            setModuleVisible(i.second, false);
-        } else if (i.first->deviceUnavailabel()) {
+        if (m_hideModuleNames.contains((i.first->name())) || i.first->deviceUnavailabel() || !i.first->isAvailable()) {
             setModuleVisible(i.second, false);
         } else if (i.first->isAvailable()) {
             setModuleVisible(i.second, true);
@@ -489,6 +494,9 @@ void MainWindow::updateModuleVisible()
 
 void MainWindow::modulePreInitialize(const QString &m)
 {
+    // 初始化后模块后直接设置模块是否显示，不需要在updateModuleVisible()中处理，避免再次遍历循环
+    m_hideModuleNames = m_moduleSettings->get(GSETTINGS_HIDE_MODULE).toStringList();
+
     for (auto it = m_modules.cbegin(); it != m_modules.cend(); ++it) {
         QElapsedTimer et;
         et.start();
@@ -499,6 +507,9 @@ void MainWindow::modulePreInitialize(const QString &m)
         if (it->first->isAvailable()) {
             // 模块有效时先初始化模块和搜索数据
             InsertPlugin::instance()->preInitialize(it->first->name());
+            setModuleVisible(it->second, !m_hideModuleNames.contains(it->first->name()) && !it->first->deviceUnavailabel());
+        } else {
+            setModuleVisible(it->second, false);
         }
     }
 }
@@ -722,6 +733,47 @@ void MainWindow::openManual()
     }
 }
 
+int MainWindow::getAppearanceFontSize()
+{
+    QDBusInterface interface("com.deepin.daemon.Appearance",
+                             "/com/deepin/daemon/Appearance",
+                             "org.freedesktop.DBus.Properties",
+                             QDBusConnection::sessionBus());
+    QDBusMessage reply = interface.call("Get", "com.deepin.daemon.Appearance", "FontSize");
+    qDebug() << reply.errorMessage();
+    QList<QVariant> outArgs = reply.arguments();
+    if (outArgs.count() > 0) {
+        int size = static_cast<int>(outArgs.at(0).value<QDBusVariant>().variant().toDouble() / 72 * 96 + 0.5);
+        qDebug() << " [getAppearanceFontSize] fontSize : " << size;
+        return size;
+    }
+    return -1;
+}
+
+void MainWindow::handleAppearanceDbusSignal(QDBusMessage message)
+{
+    QList<QVariant> arguments = message.arguments();
+    if (3 != arguments.count()) {
+        return;
+    }
+    QString interfaceName = message.arguments().at(0).toString();
+    if (interfaceName == "com.deepin.daemon.Appearance") {
+        QVariantMap changedProps = qdbus_cast<QVariantMap>(arguments.at(1).value<QDBusArgument>());
+        QStringList keys = changedProps.keys();
+        for (int i = 0; i < keys.size(); i++) {
+            if (keys.at(i) == "FontSize") {
+                int size = static_cast<int>(changedProps.value(keys.at(i)).toDouble() / 72 * 96 + 0.5);
+                qDebug() << " [handleAppearanceDbusSignal] fontSize : " << size;
+                if (m_fontSize != size) {
+                    m_fontSize = size;
+                    m_searchWidget->updateSearchdata("", m_fontSize);
+                }
+                return;
+            }
+        }
+    }
+}
+
 void MainWindow::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
@@ -868,7 +920,7 @@ void MainWindow::resetNavList(bool isIconMode)
         m_moduleName.clear();
     } else {
         //The second page will Covered with fill blank areas
-        m_navView->setViewportMargins(QMargins(10, 10, 10, 10));
+        m_navView->setViewportMargins(QMargins(10, 0, 10, 0));
         m_navView->setViewMode(QListView::ListMode);
         m_navView->setMinimumWidth(first_widget_min_width);
         m_navView->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
@@ -1058,7 +1110,7 @@ void MainWindow::updateSearchData(const QString &module)
         return;
     }
 
-    m_searchWidget->updateSearchdata(module);
+    m_searchWidget->updateSearchdata(module, m_fontSize);
 }
 
 void MainWindow::pushWidget(ModuleInterface *const inter, QWidget *const w, PushType type)
@@ -1452,3 +1504,13 @@ bool MainWindow::event(QEvent *event)
     }
     return DMainWindow::event(event);
 }
+
+bool MainWindow::showSyncModule()
+{
+    if (IsProfessionalSystem)
+        return false;
+
+    QObject raii;
+    DConfig *config = DConfig::create("com.deepin.system.mil.dconfig", "com.deepin.system.mil.dconfig", QString(), &raii);
+    return !(config && config->keyList().contains("Use_mil") && config->value("Use_mil", 1).toInt());
+}
