@@ -114,9 +114,11 @@ private Q_SLOTS:
     void findFocusChild(QWidget *w, QWidget *&pre);
     void findFocusChild(QLayout *l, QWidget *&pre);
     void openManual();
+    int getAppearanceFontSize();
+    void handleAppearanceDbusSignal(QDBusMessage message);
 
 public Q_SLOTS:
-    void updateWinsize(QRect rect = QRect(0,0,0,0));
+    void updateWinsize();
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
@@ -135,6 +137,7 @@ private:
     void judgeTopWidgetPlace(ModuleInterface *const inter, QWidget *const w);
     void updateViewBackground();
     void updateModuleVisible();
+    bool showSyncModule();
 
 private:
     bool m_bInit{false};
@@ -175,6 +178,8 @@ private:
     QPointer<QScreen> m_primaryScreen;
     int m_currentIndex = -1;
     bool m_bIsNeedChange = false;
+
+    int m_fontSize;
 };
 }
 
