@@ -19,6 +19,7 @@ const QString XML_Numerusform = "numerusform";
 const QString XML_Explain_Path = "extra-contents_path";
 const QString XML_Child_Path = "extra-child_page";
 const QString XML_ChildHide_Path = "extra-child_page_hide";
+const int TxtWidth = 310;
 
 using namespace DCC_NAMESPACE;
 using namespace DCC_NAMESPACE::search;
@@ -28,6 +29,8 @@ SearchModel::SearchModel(QObject *parent)
     , m_bIsChinese(false)
     , m_bIstextEdited(false)
     , m_dataUpdateCompleted(false)
+    , m_calLenthLabel(new QLabel)
+    , m_fontSize(0)
 {
     //左边是从从xml解析出来的数据，右边是需要被翻译成的数据；
     //后续若还有相同模块还有一样的翻译文言，也可在此处添加类似处理，并在注释处添加　//~ child_page xxx
@@ -36,6 +39,13 @@ SearchModel::SearchModel(QObject *parent)
     };
 }
 
+SearchModel::~SearchModel()
+{
+    if (m_calLenthLabel) {
+        m_calLenthLabel->deleteLater();
+    }
+}
+
 int SearchModel::getDataNum(QString source, char value)
 {
     char *data = source.toLatin1().data();
@@ -175,6 +185,7 @@ void SearchModel::loadxml(const QString module)
     m_EnterNewPagelist.clear();
     m_inputList.clear();
     m_TxtListAll.clear();
+    m_scaleTxtMap.clear();
 
     //添加一项空数据，为了防止使用setText输入错误数据时直接跳转到list中正确的第一个页面
     m_EnterNewPagelist.append(std::make_shared<SearchBoxStruct>());
@@ -262,11 +273,16 @@ void SearchModel::loadxml(const QString module)
             }
 
             if ("" == searchBoxStrcut->childPageName) {
-                appendRow(new QStandardItem(icon.value(), QString("%1 --> %2").arg(searchBoxStrcut->actualModuleName).arg(searchBoxStrcut->translateContent)));
+                appendRow(new QStandardItem(icon.value(), getNormalText(QString("%1 --> %2")
+                                                                        .arg(searchBoxStrcut->actualModuleName)
+                                                                        .arg(searchBoxStrcut->translateContent))));
             }
             else {
                 appendRow(new QStandardItem(
-                    icon.value(), QString("%1 --> %2 / %3").arg(searchBoxStrcut->actualModuleName).arg(searchBoxStrcut->childPageName).arg(searchBoxStrcut->translateContent)));
+                    icon.value(), getNormalText(QString("%1 --> %2 / %3")
+                                                .arg(searchBoxStrcut->actualModuleName)
+                                                .arg(searchBoxStrcut->childPageName)
+                                                .arg(searchBoxStrcut->translateContent))));
             }
 
             // 设置图标数据
@@ -395,7 +411,7 @@ void SearchModel::appendChineseData(SearchBoxStruct::Ptr data)
         //Qt::UserRole数据用于输入框输入的数据(拼音/汉字 均可)
         //即在输入框搜索Qt::UserRole的数据,就会在下拉框显示Qt::EditRole的数据
         appendRow(new QStandardItem(icon.value(),
-                                    QString("%1 --> %2").arg(dataBackup->actualModuleName).arg(dataBackup->translateContent)));
+                                    getNormalText(QString("%1 --> %2").arg(dataBackup->actualModuleName).arg(dataBackup->translateContent))));
 
         //设置汉字的Qt::UserRole数据
         setData(index(rowCount() - 1, 0),
@@ -416,7 +432,7 @@ void SearchModel::appendChineseData(SearchBoxStruct::Ptr data)
         if (data->actualModuleName == DTK_CORE_NAMESPACE::Chinese2Pinyin(dataBackup->actualModuleName)) return;
 
         //添加显示的汉字(用于拼音搜索显示)
-        appendRow(new QStandardItem(icon.value(), hanziTxt));
+        appendRow(new QStandardItem(icon.value(), getNormalText(hanziTxt)));
         //设置Qt::UserRole搜索的拼音(即搜索拼音会显示上面的汉字)
         setData(index(rowCount() - 1, 0), pinyinTxt, Qt::UserRole);
         setData(index(rowCount() - 1, 0), icon->name(), Qt::UserRole + 1);
@@ -432,7 +448,10 @@ void SearchModel::appendChineseData(SearchBoxStruct::Ptr data)
         //Qt::UserRole数据用于输入框输入的数据(拼音/汉字 均可)
         //即在输入框搜索Qt::UserRole的数据,就会在下拉框显示Qt::EditRole的数据
         appendRow(new QStandardItem(icon.value(),
-                                    QString("%1 --> %2 / %3").arg(dataBackup->actualModuleName).arg(dataBackup->childPageName).arg(dataBackup->translateContent)));
+                                    getNormalText(QString("%1 --> %2 / %3")
+                                                  .arg(dataBackup->actualModuleName)
+                                                  .arg(dataBackup->childPageName)
+                                                  .arg(dataBackup->translateContent))));
 
         //设置汉字的Qt::UserRole数据
         setData(index(rowCount() - 1, 0),
@@ -453,7 +472,7 @@ void SearchModel::appendChineseData(SearchBoxStruct::Ptr data)
         if (icons == m_iconMap.end()) {
             return;
         }
-        appendRow(new QStandardItem(icons.value(), hanziTxt));
+        appendRow(new QStandardItem(icons.value(), getNormalText(hanziTxt)));
         //设置Qt::UserRole搜索的拼音(即搜索拼音会显示上面的汉字)
         setData(index(rowCount() - 1, 0), pinyinTxt, Qt::UserRole);
         setData(index(rowCount() - 1, 0), icons->name(), Qt::UserRole + 1);
@@ -476,6 +495,32 @@ bool SearchModel::specialProcessData(SearchBoxStruct::Ptr data)
     return ret;
 }
 
+QString SearchModel::getNormalText(QString value)
+{
+    if (m_fontSize == 0) {
+        return value;
+    }
+
+    m_calLenthLabel->setText(value);
+    auto font = m_calLenthLabel->font();
+    font.setPixelSize(m_fontSize);
+    QFontMetrics fontMetrics(font);
+    QString ret = value;
+
+    // 字体变化了，但是没变宽度
+    if (fontMetrics.boundingRect(value).width() >= TxtWidth) {
+        ret = fontMetrics.elidedText(value, Qt::ElideRight, TxtWidth);
+        m_scaleTxtMap.insert(ret, value);
+        qDebug() << Q_FUNC_INFO << value
+                 << " font width : " << fontMetrics.boundingRect(value).width()
+                 << " font : " << m_calLenthLabel->font()
+                 << " fontSize : " << m_fontSize
+                 << " count : " << m_scaleTxtMap.count();
+    }
+
+    return ret;
+}
+
 void SearchModel::setLanguage(const QString &type)
 {
     m_lang = type;
@@ -771,10 +816,13 @@ void SearchModel::setDetailVisible(const QString &module, const QString &widget,
     }
 }
 
-void SearchModel::updateSearchData(const QString &module)
+void SearchModel::updateSearchData(const QString &module, int fontSize)
 {
-    qDebug() << "updateSearchData:" << module;
-    loadxml(module);
+    qDebug() << "updateSearchData:" << module << fontSize;
+    if (fontSize > 0) {
+        m_fontSize = fontSize;
+        loadxml(module);
+    }
 }
 
 void SearchModel::addChildPageTrans(const QString &menu, const QString &tran)
@@ -783,3 +831,8 @@ void SearchModel::addChildPageTrans(const QString &menu, const QString &tran)
         m_transChildPageName.insert(menu, tran);
     }
 }
+
+QString SearchModel::getRealTxt(const QString &key) const
+{
+    return m_scaleTxtMap.value(key) == "" ? key : m_scaleTxtMap.value(key);
+}
