@@ -107,6 +107,7 @@ SearchWidget::SearchWidget(QWidget *parent)
             if (!jumpContentPathWidget(text())) {
                 //m_completer未关联部件时，currentCompletion只会获取到第一个选项并且不会在Edit中补全内容，需要通过popup()获取当前选择项并手动补全edit内容
                 QString currentCompletion = m_completer->popup()->currentIndex().data().toString();
+                currentCompletion = m_model->getRealTxt(currentCompletion);
                 //如果通过popup()未获取当前选择项,再通过currentCompletion获取第一个选项
                 if (m_completer->completionCount() > 0 && currentCompletion.isEmpty()) {
                     currentCompletion = m_completer->currentCompletion();
@@ -145,6 +146,7 @@ SearchWidget::~SearchWidget()
 void SearchWidget::onCompleterActivated(const QString &value)
 {
     qDebug() << Q_FUNC_INFO << value;
+    onSelectCompleterSacleData(value);
     Q_EMIT returnPressed();
 }
 
@@ -177,6 +179,22 @@ void SearchWidget::onSearchTextChange(const QString &text)
     onAutoComplete(text);
 }
 
+// 处理显示数据过长替换为...结尾的数据，转换为真实数据设置到搜索框
+void SearchWidget::onSelectCompleterSacleData(QString text)
+{
+    if (!m_model || !m_completer)
+        return;
+
+    QString editTxt = m_completer->popup()->currentIndex().data().toString();
+    if (editTxt.contains("…")) {
+        QString value = m_model->getRealTxt(editTxt);
+        if (value != editTxt && value != "") {
+            qDebug() << Q_FUNC_INFO << " enter txt : "<< text << " , Real txt : " << value;
+            this->setText(value);
+        }
+    }
+}
+
 bool ddeCompleter::eventFilter(QObject *o, QEvent *e)
 {
     // 匹配列表隐藏时，将滑动条恢复到顶部
@@ -283,13 +301,13 @@ void SearchWidget::setDetailVisible(const QString &module, const QString &widget
     m_model->setDetailVisible(module, widget, detail, visible);
 }
 
-void SearchWidget::updateSearchdata(const QString &module)
+void SearchWidget::updateSearchdata(const QString &module, int fontSize)
 {
     if (!m_model) {
         return;
     }
 
-    m_model->updateSearchData(module);
+    m_model->updateSearchData(module, fontSize);
 }
 
 //返回搜索结果
