@@ -1,30 +1,32 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en_US">
 <context>
     <name>ReminderDialog</name>
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="14"/>
         <source>Restart the computer to use the system and the applications properly</source>
-        <translation>Restart the computer to use the system and the applications properly</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="15"/>
         <source>Make sure all data had been saved first</source>
-        <translation>Make sure all data had been saved first</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="20"/>
         <source>Cancel</source>
-        <translation>Cancel</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="20"/>
         <source>Shut down</source>
-        <translation>Shut down</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="23"/>
         <source>Reboot</source>
-        <translation>Reboot</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
