@@ -629,7 +629,7 @@
     <message>
         <location filename="language.h" line="156"/>
         <source>Українська</source>
-        <translation>Ukrajinský</translation>
+        <translation>Українська</translation>
     </message>
     <message>
         <location filename="language.h" line="157"/>
