@@ -404,7 +404,7 @@
     <message>
         <location filename="language.h" line="111"/>
         <source>Norsk (bokmål)</source>
-        <translation>Norvég</translation>
+        <translation>Norsk (bokmål)</translation>
     </message>
     <message>
         <location filename="language.h" line="112"/>
@@ -464,7 +464,7 @@
     <message>
         <location filename="language.h" line="123"/>
         <source>Polski</source>
-        <translation>Lengyel</translation>
+        <translation>Polski</translation>
     </message>
     <message>
         <location filename="language.h" line="124"/>
