@@ -213,7 +213,7 @@
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="114"/>
         <source>What&apos;s the name of the first school you attended?</source>
-        <translation>Как называется первая школа, в которую ты пошел?</translation>
+        <translation>Как называется первая школа, в которую вы ходили?</translation>
     </message>
     <message>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="115"/>
